# Changelog

This page lists the key changes made between consecutive versions of PySLSQP.
A more detailed description of major changes between releases can be found
in [`RELEASE_NOTES.md`](https://github.com/anugrahjo/PySLSQP/blob/main/release_notes.md) 
in the project root directory.

***********************************
## Version 0.1.0 (June 2, 2024)

- Initial release of PySLSQP